(v1.9.4)=
### 1.9.4 {small}`2023-08-24`

#### Bug fixes

* Support scikit-learn 1.3 {pr}`2515` {smaller}`P Angerer`
* Deal with `None` value vanishing from things like `.uns['log1p']` {pr}`2546` {smaller}`SP Shen`
* Depend on `igraph` instead of `python-igraph` {pr}`2566` {smaller}`P Angerer`
* {func}`~scanpy.tl.rank_genes_groups` now handles unsorted groups as intended {pr}`2589` {smaller}`S Dicks`
* {func}`~scanpy.get.rank_genes_groups_df` now works for {func}`~scanpy.tl.rank_genes_groups` with `method="logreg"` {pr}`2601` {smaller}`S Dicks`
* `scanpy.tl._utils._choose_representation` now works with `n_pcs` if bigger than `settings.N_PCS` {pr}`2610` {smaller}`S Dicks`
